@@ -27,6 +27,7 @@
  * present.
  */
 
+
 #include <stdio.h>
 #include <string.h>
 #include <ctype.h>
@@ -264,7 +265,7 @@ static const char *attr_int_table[NV_CTRL_LAST_ATTRIBUTE + 1] = {
     MAKE_ENTRY(NV_CTRL_THERMAL_COOLER_SPEED),
     MAKE_ENTRY(NV_CTRL_PALETTE_UPDATE_EVENT),
     MAKE_ENTRY(NV_CTRL_VIDEO_ENCODER_UTILIZATION),
-    MAKE_ENTRY(NV_CTRL_GSYNC_ALLOWED),
+    MAKE_ENTRY(NV_CTRL_VRR_ALLOWED),
     MAKE_ENTRY(NV_CTRL_GPU_NVCLOCK_OFFSET),
     MAKE_ENTRY(NV_CTRL_GPU_MEM_TRANSFER_RATE_OFFSET),
     MAKE_ENTRY(NV_CTRL_VIDEO_DECODER_UTILIZATION),
@@ -272,9 +273,11 @@ static const char *attr_int_table[NV_CTRL_LAST_ATTRIBUTE + 1] = {
     MAKE_ENTRY(NV_CTRL_GPU_CURRENT_CORE_VOLTAGE),
     MAKE_ENTRY(NV_CTRL_CURRENT_COLOR_SPACE),
     MAKE_ENTRY(NV_CTRL_CURRENT_COLOR_RANGE),
-    MAKE_ENTRY(NV_CTRL_SHOW_GSYNC_VISUAL_INDICATOR),
+    MAKE_ENTRY(NV_CTRL_SHOW_VRR_VISUAL_INDICATOR),
     MAKE_ENTRY(NV_CTRL_THERMAL_COOLER_CURRENT_LEVEL),
     MAKE_ENTRY(NV_CTRL_STEREO_SWAP_MODE),
+    MAKE_ENTRY(NV_CTRL_DISPLAY_VRR_MODE),
+    MAKE_ENTRY(NV_CTRL_DISPLAY_VRR_MIN_REFRESH_RATE),
 };
 
 // grep 'define.*\/\*' NVCtrl.h | grep -v NV_CTRL_TARGET_TYPE_ | grep -v "not supported" | grep -v "renamed" | grep -v "deprecated" | grep NV_CTRL_STRING_ | grep -v NV_CTRL_STRING_OPERATION_ | sed 's/.*define \([^ ]*\).*/    MAKE_ENTRY(\1),/'
