@@ -41,45 +41,38 @@
 
 
 
-/*
- * display_device_name() - return the display device name corresponding
- * to the display device mask.
- */
-
-static char *display_device_name(int mask)
+static void print_target_indices(const char *prefix, const int *pData)
 {
-    switch (mask) {
-    case (1 <<  0): return "CRT-0"; break;
-    case (1 <<  1): return "CRT-1"; break;
-    case (1 <<  2): return "CRT-2"; break;
-    case (1 <<  3): return "CRT-3"; break;
-    case (1 <<  4): return "CRT-4"; break;
-    case (1 <<  5): return "CRT-5"; break;
-    case (1 <<  6): return "CRT-6"; break;
-    case (1 <<  7): return "CRT-7"; break;
+    int i, first = 1;
 
-    case (1 <<  8): return "TV-0"; break;
-    case (1 <<  9): return "TV-1"; break;
-    case (1 << 10): return "TV-2"; break;
-    case (1 << 11): return "TV-3"; break;
-    case (1 << 12): return "TV-4"; break;
-    case (1 << 13): return "TV-5"; break;
-    case (1 << 14): return "TV-6"; break;
-    case (1 << 15): return "TV-7"; break;
-
-    case (1 << 16): return "DFP-0"; break;
-    case (1 << 17): return "DFP-1"; break;
-    case (1 << 18): return "DFP-2"; break;
-    case (1 << 19): return "DFP-3"; break;
-    case (1 << 20): return "DFP-4"; break;
-    case (1 << 21): return "DFP-5"; break;
-    case (1 << 22): return "DFP-6"; break;
-    case (1 << 23): return "DFP-7"; break;
-    default: return "Unknown";
+    for (i = 1; i <= pData[0]; i++) {
+        if (!first) {
+            printf(", ");
+        }
+        first = 0;
+        printf("%s-%d", prefix, pData[i]);
     }
-} /* display_device_name() */
+}
 
+static void print_display_device_target_indices(const int *pData)
+{
+    print_target_indices("DPY", pData);
+}
 
+static void print_cooler_target_indices(const int *pData)
+{
+    print_target_indices("COOLER", pData);
+}
+
+static void print_thermal_sensor_target_indices(const int *pData)
+{
+    print_target_indices("THERMAL-SENSOR", pData);
+}
+
+static void print_framelock_target_indices(const int *pData)
+{
+    print_target_indices("FRAMELOCK", pData);
+}
 
 int main(int argc, char *argv[])
 {
@@ -94,7 +87,6 @@ int main(int argc, char *argv[])
     int num_coolers;
     int num_thermal_sensors;
     int gpu, screen;
-    int display_devices, mask;
     int *pData;
     int len, j;
     char *str;
@@ -156,6 +148,26 @@ int main(int argc, char *argv[])
     printf("  number of X Screens: %d\n", num_screens);
 
 
+    /* Get the number of display devices in the system */
+
+    ret = XNVCTRLQueryTargetBinaryData
+        (dpy,
+         NV_CTRL_TARGET_TYPE_GPU,
+         0, // target_id
+         0, // display_mask
+         NV_CTRL_BINARY_DATA_DISPLAY_TARGETS,
+         (unsigned char **) &pData,
+         &len);
+    if (!ret) {
+        fprintf(stderr, "Failed to query number of display devices\n");
+        return 1;
+    }
+    printf("  number of display devices: %d (", pData[0]);
+    print_display_device_target_indices(pData);
+    printf(")\n");
+    XFree(pData);
+
+
     /* Get the number of Frame Lock devices in the system */
 
     ret = XNVCTRLQueryTargetCount(dpy, NV_CTRL_TARGET_TYPE_FRAMELOCK,
@@ -221,6 +233,8 @@ int main(int argc, char *argv[])
 
     for (gpu = 0; gpu < num_gpus; gpu++) {
 
+        int *pDisplayData;
+
         printf("\n\n");
         printf("GPU %d information:\n", gpu);
 
@@ -254,37 +268,81 @@ int main(int argc, char *argv[])
         XFree(str);
         str = NULL;
 
+        /* Coolers on GPU */
+
+        ret = XNVCTRLQueryTargetBinaryData
+            (dpy,
+             NV_CTRL_TARGET_TYPE_GPU,
+             gpu, // target_id
+             0, // display_mask
+             NV_CTRL_BINARY_DATA_COOLERS_USED_BY_GPU,
+             (unsigned char **) &pData,
+             &len);
+        if (!ret) {
+            fprintf(stderr, "Failed to query connected coolers\n");
+            return 1;
+        }
+        printf("   Coolers on GPU                  : ");
+        print_cooler_target_indices(pData);
+        XFree(pData);
+        printf("\n");
+
+        /* Thermal Sensors on GPU */
+
+        ret = XNVCTRLQueryTargetBinaryData
+            (dpy,
+             NV_CTRL_TARGET_TYPE_GPU,
+             gpu, // target_id
+             0, // display_mask
+             NV_CTRL_BINARY_DATA_THERMAL_SENSORS_USED_BY_GPU,
+             (unsigned char **) &pData,
+             &len);
+        if (!ret) {
+            fprintf(stderr, "Failed to query connected thermal sensors\n");
+            return 1;
+        }
+        printf("   Thermal Sensors on GPU          : ");
+        print_thermal_sensor_target_indices(pData);
+        XFree(pData);
+        printf("\n");
+
         /* Connected Display Devices on GPU */
 
-        ret = XNVCTRLQueryTargetAttribute(dpy,
-                                          NV_CTRL_TARGET_TYPE_GPU,
-                                          gpu, // target_id
-                                          0, // display_mask
-                                          NV_CTRL_CONNECTED_DISPLAYS,
-                                          &display_devices);
+        ret = XNVCTRLQueryTargetBinaryData
+            (dpy,
+             NV_CTRL_TARGET_TYPE_GPU,
+             gpu, // target_id
+             0, // display_mask
+             NV_CTRL_BINARY_DATA_DISPLAYS_CONNECTED_TO_GPU,
+             (unsigned char **) &pDisplayData,
+             &len);
         if (!ret) {
             fprintf(stderr, "Failed to query connected displays\n");
             return 1;
         }
-        printf("   Display Device Mask (Connected) : 0x%08x\n",
-               display_devices);
+        printf("   Connected Display Devices       : ");
+        print_display_device_target_indices(pDisplayData);
+        XFree(pDisplayData);
+        printf("\n");
 
+        /* FrameLock Devices on GPU */
 
-        /* Enabled Display Devices on GPU */
-
-        ret = XNVCTRLQueryTargetAttribute(dpy,
-                                          NV_CTRL_TARGET_TYPE_GPU,
-                                          gpu, // target_id
-                                          0, // display_mask
-                                          NV_CTRL_ENABLED_DISPLAYS,
-                                          &display_devices);
+        ret = XNVCTRLQueryTargetBinaryData
+            (dpy,
+             NV_CTRL_TARGET_TYPE_GPU,
+             gpu, // target_id
+             0, // display_mask
+             NV_CTRL_BINARY_DATA_FRAMELOCKS_USED_BY_GPU,
+             (unsigned char **) &pData,
+             &len);
         if (!ret) {
-            fprintf(stderr, "Failed to query enabled displays\n");
+            fprintf(stderr, "Failed to query framelock devices\n");
             return 1;
         }
-        printf("   Display Device Mask (Enabled)   : 0x%08x\n",
-               display_devices);
-         
+        printf("   Framelock Devices               : ");
+        print_framelock_target_indices(pData);
+        XFree(pData);
+        printf("\n");
 
         /* X Screens driven by this GPU */
 
@@ -307,64 +365,47 @@ int main(int argc, char *argv[])
 
         for (j = 1; j <= pData[0]; j++) {
             screen = pData[j];
-            
+
             printf("\n");
             printf("   X Screen %d information:\n", screen);
 
+            /* Assigned Display Devices on X Screen */
 
-            /* Connected Display Devices on X Screen */
-
-            ret = XNVCTRLQueryTargetAttribute(dpy,
-                                              NV_CTRL_TARGET_TYPE_X_SCREEN,
-                                              screen, // target_id
-                                              0, // display_mask
-                                              NV_CTRL_CONNECTED_DISPLAYS,
-                                              &display_devices);
+            ret = XNVCTRLQueryTargetBinaryData
+                (dpy,
+                 NV_CTRL_TARGET_TYPE_X_SCREEN,
+                 screen, // target_id
+                 0, // display_mask
+                 NV_CTRL_BINARY_DATA_DISPLAYS_ASSIGNED_TO_XSCREEN,
+                 (unsigned char **) &pDisplayData,
+                 &len);
             if (!ret) {
-                fprintf(stderr, "Failed to query connected displays\n");
-                XFree(pData);
+                fprintf(stderr, "Failed to query assigned displays\n");
                 return 1;
             }
-            printf("      Display Device Mask (Connected) : 0x%08x\n",
-                   display_devices);
-            
+            printf("       Assigned Display Devices    : ");
+            print_display_device_target_indices(pDisplayData);
+            XFree(pDisplayData);
+            printf("\n");
 
             /* Enabled Display Devices on X Screen */
 
-            ret = XNVCTRLQueryTargetAttribute(dpy,
-                                              NV_CTRL_TARGET_TYPE_X_SCREEN,
-                                              screen, // target_id
-                                              0, // display_mask
-                                              NV_CTRL_ENABLED_DISPLAYS,
-                                              &display_devices);
+            ret = XNVCTRLQueryTargetBinaryData
+                (dpy,
+                 NV_CTRL_TARGET_TYPE_X_SCREEN,
+                 screen, // target_id
+                 0, // display_mask
+                 NV_CTRL_BINARY_DATA_DISPLAYS_ENABLED_ON_XSCREEN,
+                 (unsigned char **) &pDisplayData,
+                 &len);
             if (!ret) {
-                fprintf(stderr, "Failed to query enabled displays\n");
-                XFree(pData);
+                fprintf(stderr, "Failed to query assigned displays\n");
                 return 1;
             }
-            printf("      Display Device Mask (Enabled)   : 0x%08x\n",
-                   display_devices);
-            
-
-            /* List all display devices on this X Screen */
-
-            for (mask = 1; mask < (1 << 24); mask <<= 1) {
-                if (!(display_devices & mask)) {
-                    continue;
-                }
-
-                ret = XNVCTRLQueryTargetStringAttribute
-                    (dpy,
-                     NV_CTRL_TARGET_TYPE_X_SCREEN,
-                     screen, // target_id
-                     mask, // display_mask
-                     NV_CTRL_STRING_DISPLAY_DEVICE_NAME,
-                     &str);
-                printf("      Display Device (0x%08x) : %s - '%s'\n",
-                       mask,
-                       display_device_name(mask),
-                       str);
-            }
+            printf("       Enabled Display Devices     : ");
+            print_display_device_target_indices(pDisplayData);
+            XFree(pDisplayData);
+            printf("\n");
         }
         XFree(pData);
     }
