@@ -1,17 +1,23 @@
 /*
  * Copyright (C) 2004-2010 NVIDIA Corporation
  *
- * This program is free software; you can redistribute it and/or modify it
- * under the terms and conditions of the GNU General Public License,
- * version 2, as published by the Free Software Foundation.
+ * Permission is hereby granted, free of charge, to any person obtaining a
+ * copy of this software and associated documentation files (the "Software"),
+ * to deal in the Software without restriction, including without limitation
+ * the rights to use, copy, modify, merge, publish, distribute, sublicense,
+ * and/or sell copies of the Software, and to permit persons to whom the
+ * Software is furnished to do so, subject to the following conditions:
  *
- * This program is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
- * more details.
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, see <http://www.gnu.org/licenses>.
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
+ * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
+ * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
+ * DEALINGS IN THE SOFTWARE.
  *
  *
  * nvgetopt.c - portable getopt_long() replacement; removes the need
@@ -21,8 +27,11 @@
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
+#include <ctype.h>
+#include <limits.h>
 
 #include "nvgetopt.h"
+#include "common-utils.h"
 
 
 int nvgetopt(int argc,
@@ -39,6 +48,7 @@ int nvgetopt(int argc,
     int ret = 0;
     int negate = NVGETOPT_FALSE;
     int disable = NVGETOPT_FALSE;
+    int double_dash = NVGETOPT_FALSE;
     const NVGetoptOption *o = NULL;
     static int argv_index = 0;
 
@@ -62,6 +72,7 @@ int nvgetopt(int argc,
 
     if ((arg[0] == '-') && (arg[1] == '-')) {
         name = arg + 2;
+        double_dash = NVGETOPT_TRUE;
     } else if (arg[0] == '-') {
         name = arg + 1;
     } else {
@@ -77,16 +88,26 @@ int nvgetopt(int argc,
 
     c = name;
     while (*c) {
-        if (*c == '=') { argument = c + 1; *c = '\0'; break; }
+        if (*c == '=') {
+            argument = c + 1;
+            *c = '\0';
+            break;
+        }
         c++;
     }
 
     /*
+     * if there is no character after '--' then stop processing options.
      * if the string is terminated after one character, interpret it
      * as a short option.  Otherwise, interpret it as a long option.
      */
 
-    if (name[1] == '\0') { /* short option */
+    if (name[0] == '\0') {
+        if (double_dash && argument == NULL) { /* option list terminator */
+            ret = -1;
+            goto done;
+        }
+    } else if (name[1] == '\0') { /* short option */
         for (i = 0; options[i].name; i++) {
             if (options[i].val == name[0]) {
                 o = &options[i];
@@ -184,6 +205,41 @@ int nvgetopt(int argc,
         }
     }
 
+    /*
+     * If we still didn't find a match, maybe this is a short option
+     * with its argument value concatenated (e.g., "-j8").  For now,
+     * limit this to short options with integer argument values.
+     */
+    if (!o && intval) {
+
+        /* Is the string after the first character an integer? */
+        int appendedInteger = NVGETOPT_FALSE;
+        if ((name[0] != '\0') && (name[1] != '\0')) {
+            char *endptr;
+            strtol(name + 1, &endptr, 0);
+            if (*endptr == '\0') {
+                /*
+                 * The only characters after the first character are
+                 * parsable by strtol(3).
+                 */
+                appendedInteger = NVGETOPT_TRUE;
+            }
+        }
+
+        if (appendedInteger) {
+            for (i = 0; options[i].name; i++) {
+                if ((options[i].flags & NVGETOPT_INTEGER_ARGUMENT) == 0) {
+                    continue;
+                }
+                if (options[i].val == name[0]) {
+                    o = &options[i];
+                    argument = name + 1;
+                    break;
+                }
+            }
+        }
+    }
+
     /* if we didn't find an option, return */
 
     if (!o) {
@@ -309,3 +365,126 @@ int nvgetopt(int argc,
     return ret;
 
 } /* nvgetopt() */
+
+
+/*
+ * cook_description() - the description string may contain text within
+ * special characters which are interpreted by the manpage generator.
+ * We want to omit those characters here.
+ */
+
+static char *cook_description(const char *description)
+{
+    const char *src;
+    char *s, *dst;
+
+    if (!description) {
+        return NULL;
+    }
+
+    s = strdup(description);
+
+    if (!s) {
+        return NULL;
+    }
+
+    for (src = description, dst = s; *src; src++) {
+        if ((*src == '&') || (*src == '^')) {
+            continue;
+        }
+        *dst = *src;
+        dst++;
+    }
+
+    *dst = '\0';
+
+    return s;
+}
+
+
+void nvgetopt_print_help(const NVGetoptOption *options,
+                         unsigned int include_mask,
+                         nvgetopt_print_help_callback_ptr callback)
+{
+    const NVGetoptOption *o;
+    int i;
+
+    for (i = 0; options[i].name; i++) {
+
+        char *msg = NULL, *arg = NULL, *description = NULL;
+
+        o = &options[i];
+
+        /* Skip options with no help text */
+        if (!o->description) {
+            continue;
+        }
+
+        /* skip options who don't have all the bits of include_mask */
+        if ((o->flags & include_mask) != include_mask) {
+            continue;
+        }
+
+        /* if we are going to need the argument, process it now */
+        arg = NULL;
+        if (o->flags & NVGETOPT_HAS_ARGUMENT) {
+            if (o->arg_name) {
+                arg = strdup(o->arg_name);
+            } else {
+                char *tmp;
+                arg = strdup(o->name);
+                for (tmp = arg; tmp && *tmp; tmp++) {
+                    *tmp = toupper(*tmp);
+                }
+            }
+        }
+
+        msg = NULL;
+
+        /*
+         * create the long version of the option, possibly with an
+         * argument; e.g., "--foo" or "--foo=BAR"
+         */
+        if (arg) {
+            msg = nvstrcat("--", o->name, "=", arg, NULL);
+        } else {
+            msg = nvstrcat("--", o->name, NULL);
+        }
+
+        /*
+         * prepend the single character version of the option,
+         * possibly with an argument; e.g., "-f" or "-f BAR"
+         */
+        if (o->val <= UCHAR_MAX && o->val >= 0 && isalpha(o->val)) {
+            char scratch[16];
+            char *tmp;
+            snprintf(scratch, sizeof(scratch), "%c", o->val);
+            if (arg) {
+                tmp = nvstrcat("-", scratch, " ", arg, ", ", msg, NULL);
+            } else {
+                tmp = nvstrcat("-", scratch, ", ", msg, NULL);
+            }
+            free(msg);
+            msg = tmp;
+        }
+
+        /* append the boolean version of the option; e.g., "--no-foo" */
+        if (((o->flags & NVGETOPT_IS_BOOLEAN) &&
+             !(o->flags & NVGETOPT_HAS_ARGUMENT)) ||
+            (o->flags & NVGETOPT_ALLOW_DISABLE)) {
+            char *tmp = nvstrcat(msg, ", --no-", o->name, NULL);
+            free(msg);
+            msg = tmp;
+        }
+
+        /* process the description text */
+        description = cook_description(o->description);
+
+        /* give the strings to the caller to format and print */
+        callback(msg, description);
+
+        free(msg);
+        free(arg);
+        free(description);
+    }
+}
