@@ -50,23 +50,23 @@ typedef enum {
     BANNER_ARTWORK_COLOR,
     BANNER_ARTWORK_CONFIG,
     BANNER_ARTWORK_CRT,
-    BANNER_ARTWORK_CURSOR_SHADOW,
     BANNER_ARTWORK_DFP,
     BANNER_ARTWORK_DISPLAY_CONFIG,
     BANNER_ARTWORK_FRAMELOCK,
-    BANNER_ARTWORK_GLX,
     BANNER_ARTWORK_GPU,
+    BANNER_ARTWORK_GRAPHICS,
     BANNER_ARTWORK_GVI,
     BANNER_ARTWORK_HELP,
     BANNER_ARTWORK_OPENGL,
     BANNER_ARTWORK_PENGUIN,
     BANNER_ARTWORK_SDI,
     BANNER_ARTWORK_SDI_SHARED_SYNC_BNC,
+    BANNER_ARTWORK_SERVER_LICENSING,
     BANNER_ARTWORK_SLIMM,
     BANNER_ARTWORK_SOLARIS,
     BANNER_ARTWORK_THERMAL,
-    BANNER_ARTWORK_TV,
     BANNER_ARTWORK_VCS,
+    BANNER_ARTWORK_VDPAU,
     BANNER_ARTWORK_X,
     BANNER_ARTWORK_XVIDEO,
     BANNER_ARTWORK_SVP,
