@@ -65,6 +65,7 @@ static gboolean update_connector_type_info(InfoEntry *entry);
 static gboolean update_multistream_info(InfoEntry *entry);
 static gboolean update_audio_info(InfoEntry *entry);
 static gboolean update_vrr_type_info(InfoEntry *entry);
+static gboolean update_vrr_enabled_info(InfoEntry *entry);
 
 static gboolean register_link_events(InfoEntry *entry);
 static gboolean unregister_link_events(InfoEntry *entry);
@@ -120,6 +121,13 @@ static const char * __vrr_type_help =
 "Report whether the configured display supports G-SYNC, G-SYNC Compatible, or "
 "neither.";
 
+static const char * __vrr_enabled_help =
+"Report whether the configured display enabled variable refresh mode at "
+"modeset time.  On displays capable of variable refresh mode but which are not "
+"validated as G-SYNC compatible, variable refresh mode can be enabled on the X "
+"Server Display Configuration page, or by using the AllowGSYNCCompatible "
+"MetaMode attribute.";
+
 typedef gboolean (*InfoEntryFunc)(InfoEntry *entry);
 
 typedef struct {
@@ -201,6 +209,13 @@ static InfoEntryData __info_entry_data[] = {
         NULL,
         NULL,
     },
+    {
+        "G-SYNC Mode Enabled",
+        &__vrr_enabled_help,
+        update_vrr_enabled_info,
+        NULL,
+        NULL,
+    },
 };
 
 GType ctk_display_device_get_type(void)
@@ -721,7 +736,7 @@ static gboolean update_link_info(InfoEntry *entry)
     ReturnStatus ret;
     gint val;
     const char *link;
-    char tmp[32];
+    char tmp[64];
 
     ret = NvCtrlGetAttribute(ctrl_target, NV_CTRL_FLATPANEL_LINK, &val);
     if (ret != NvCtrlSuccess) {
@@ -744,11 +759,13 @@ static gboolean update_link_info(InfoEntry *entry)
             }
 
             if (val > 0) {
-                snprintf(tmp, 32, "%d lane%s @ %.2f Gbps", lanes, lanes == 1 ? "" : "s",
+                snprintf(tmp, sizeof(tmp),
+                         "%d lane%s @ %.2f Gbps", lanes, lanes == 1 ? "" : "s",
                          val * 0.27);
             } else {
-                snprintf(tmp, 32, "%d lane%s @ unknown bandwidth", lanes,
-                         lanes == 1 ? "" : "s");
+                snprintf(tmp, sizeof(tmp),
+                         "%d lane%s @ unknown bandwidth",
+                         lanes, lanes == 1 ? "" : "s");
             }
             link = tmp;
         }
@@ -884,6 +901,24 @@ static gboolean update_vrr_type_info(InfoEntry *entry)
     return TRUE;
 }
 
+static gboolean update_vrr_enabled_info(InfoEntry *entry)
+{
+    CtkDisplayDevice *ctk_object = entry->ctk_object;
+    CtrlTarget *ctrl_target = ctk_object->ctrl_target;
+    ReturnStatus ret;
+    gint val;
+
+    ret = NvCtrlGetAttribute(ctrl_target,
+                             NV_CTRL_DISPLAY_VRR_ENABLED, &val);
+    if (ret != NvCtrlSuccess) {
+        return FALSE;
+    }
+
+    gtk_label_set_text(GTK_LABEL(entry->txt), val ? "Yes" : "No");
+
+    return TRUE;
+}
+
 
 
 
