@@ -34,43 +34,16 @@
 #include "ctkutils.h"
 #include "ctkbanner.h"
 
-static const _CtkStereoMode stereoMode[] = {
-    { NV_CTRL_STEREO_OFF,                          "Stereo Disabled" },
-    { NV_CTRL_STEREO_DDC,                          "DDC Stereo" },
-    { NV_CTRL_STEREO_BLUELINE,                     "Blueline Stereo" },
-    { NV_CTRL_STEREO_DIN,                          "Onboard DIN Stereo" },
-    { NV_CTRL_STEREO_PASSIVE_EYE_PER_DPY,          "Passive One-Eye-per-Display Stereo" },
-    { NV_CTRL_STEREO_VERTICAL_INTERLACED,          "Vertical Interlaced Stereo" },
-    { NV_CTRL_STEREO_COLOR_INTERLACED,             "Color Interleaved Stereo" },
-    { NV_CTRL_STEREO_HORIZONTAL_INTERLACED,        "Horizontal Interlaced Stereo" },
-    { NV_CTRL_STEREO_CHECKERBOARD_PATTERN,         "Checkerboard Pattern Stereo" },
-    { NV_CTRL_STEREO_INVERSE_CHECKERBOARD_PATTERN, "Inverse Checkerboard Stereo" },
-    { NV_CTRL_STEREO_3D_VISION,                    "NVIDIA 3D Vision Stereo" },
-    { NV_CTRL_STEREO_3D_VISION_PRO,                "NVIDIA 3D Vision Pro Stereo" },
-    { -1, NULL},
-};
+#include "ctkglwidget.h"
+#include "ctkglstereo.h"
 
 void ctk_screen_event_handler(GtkWidget *widget,
-                              XRRScreenChangeNotifyEvent *ev,
+                              CtrlEvent *event,
                               gpointer data);
 
-static void associated_displays_received(GtkObject *object, gpointer arg1,
-                                         gpointer user_data);
-
-static void info_update_gpu_error(GtkObject *object, gpointer arg1,
+static void info_update_gpu_error(GObject *object, gpointer arg1,
                                       gpointer user_data);
 
-static const char *get_stereo_mode_string(int stereo_mode)
-{
-    int i;
-    for (i = 0; stereoMode[i].name; i++) {
-        if (stereoMode[i].stereo_mode == stereo_mode) {
-            return stereoMode[i].name;
-        }
-    }
-    return "Unknown";
-}
-
 GType ctk_screen_get_type(
     void
 )
@@ -88,6 +61,7 @@ GType ctk_screen_get_type(
             sizeof (CtkScreen),
             0, /* n_preallocs */
             NULL, /* instance_init */
+            NULL  /* value_table */
         };
 
         ctk_screen_type =
@@ -100,156 +74,26 @@ GType ctk_screen_get_type(
 
 
 
-/* Generates a list of display device names for those display devices that
- * are enabled on the given GPU and, if Xinerama is disabled, are also
- * associated to the given X screen (handle).
- */
-static gchar *make_gpu_display_device_list(NvCtrlAttributeHandle *handle,
-                                           int gpu_id,
-                                           int xinerama_enabled)
-{
-    gchar *displays = NULL;
-    gchar *type;
-    gchar *name;
-    gchar *tmp_str;
-    unsigned int display_devices;
-    unsigned int mask;
-    Bool valid;
-
-
-    /* Get the list of enabled display devices on the GPU */
-
-    valid =
-        XNVCTRLQueryTargetAttribute(NvCtrlGetDisplayPtr(handle),
-                                    NV_CTRL_TARGET_TYPE_GPU,
-                                    gpu_id,
-                                    0,
-                                    NV_CTRL_ENABLED_DISPLAYS,
-                                    (int *)&display_devices);
-    if (!valid) return NULL;
-
-    /* If Xinerama is disabled, only show displays that are associated
-     * to this X screen.
-     */
-    if (!xinerama_enabled) {
-        ReturnStatus ret;
-        unsigned int associated_devices;
-
-        ret = NvCtrlGetAttribute(handle,
-                                 NV_CTRL_ASSOCIATED_DISPLAY_DEVICES,
-                                 (int *)&associated_devices);
-        if (ret == NvCtrlSuccess) {
-            display_devices &= associated_devices;
-        }
-    }
-
-    /* Make the list of display device names */
-
-    for (mask = 1; mask; mask <<= 1) {
-
-        if (!(mask & display_devices)) continue;
-
-        type = display_device_mask_to_display_device_name(mask);
-        name = NULL;
-
-        valid =
-            XNVCTRLQueryTargetStringAttribute(NvCtrlGetDisplayPtr(handle),
-                                              NV_CTRL_TARGET_TYPE_GPU,
-                                              gpu_id,
-                                              mask,
-                                              NV_CTRL_STRING_DISPLAY_DEVICE_NAME,
-                                              &name);
-        if (!valid) {
-            tmp_str = g_strdup_printf("Unknown (%s)", type);
-        } else {
-            tmp_str = g_strdup_printf("%s (%s)", name, type);
-            XFree(name);
-        }
-        free(type);
-
-        if (displays) {
-            name = g_strdup_printf("%s,\n%s", tmp_str, displays);
-            g_free(displays);
-            g_free(tmp_str);
-        } else {
-            name = tmp_str;
-        }
-        displays = name;
-    }
-
-    return displays;
-}
-
-
-
 /* Generates a list of display devices for the logical X screen
- * given as "handle".
+ * given as CtrlTarget.
  */
-static gchar *make_display_device_list(NvCtrlAttributeHandle *handle)
+static gchar *make_display_device_list(CtrlTarget *ctrl_target)
 {
-    ReturnStatus ret;
-    int len;
-    int i;
-    int *pData;
-    gchar *displays = NULL;
-    int xinerama_enabled;
-
-
-    /* See if Xinerama is enabled */
-    ret = NvCtrlGetAttribute(handle, NV_CTRL_XINERAMA, &xinerama_enabled);
-    if (ret != NvCtrlSuccess) {
-        goto done;
-    }
-
-    /* Get all GPUs driving this X screen */
-    ret = NvCtrlGetBinaryAttribute(handle,
-                                   0,
-                                   NV_CTRL_BINARY_DATA_GPUS_USED_BY_LOGICAL_XSCREEN,
-                                   (unsigned char **)(&pData),
-                                   &len);
-    if (ret != NvCtrlSuccess) {
-        goto done;
-    }
-
-    /* Generate the list of display device names that display this X screen */
-    for (i = 1; i <= pData[0]; i++) {
-        gchar *new_str;
-        gchar *tmp_str;
-
-        new_str = make_gpu_display_device_list(handle, pData[i],
-                                               xinerama_enabled);
-        if (new_str) {
-            if (displays) {
-                tmp_str = g_strdup_printf("%s,\n%s", displays, new_str);
-                g_free(displays);
-                g_free(new_str);
-                displays = tmp_str;
-            } else {
-                displays = new_str;
-            }
-        }
-    }
-
- done:
-    if (!displays) {
-        displays = g_strdup("None");
-    }
-
-    return displays;
-
+    return create_display_name_list_string(ctrl_target,
+                                           NV_CTRL_BINARY_DATA_DISPLAYS_ENABLED_ON_XSCREEN);
 } /* make_display_device_list() */
 
 
 
 /*
  * Calculations of the screen dimensions and resolution are based on
- * the dxpyinfo utility code.
+ * the xdpyinfo utility code.
  *
  * Copyright Information for xdpyinfo:
  *
  ***********************************************************************
  * 
- * xdpyinfo - print information about X display connecton
+ * xdpyinfo - print information about X display connection
  *
  * 
 Copyright 1988, 1998  The Open Group
@@ -280,8 +124,7 @@ in this Software without prior written authorization from The Open Group.
  *
  */
 
-GtkWidget* ctk_screen_new(NvCtrlAttributeHandle *handle,
-                          CtkEvent *ctk_event)
+GtkWidget* ctk_screen_new(CtrlTarget *ctrl_target, CtkEvent *ctk_event)
 {
     GObject *object;
     CtkScreen *ctk_screen;
@@ -291,6 +134,7 @@ GtkWidget* ctk_screen_new(NvCtrlAttributeHandle *handle,
     GtkWidget *banner;
     GtkWidget *hseparator;
     GtkWidget *table;
+    GtkWidget *ctk_glstereo;
 
     ReturnStatus ret;
 
@@ -316,15 +160,15 @@ GtkWidget* ctk_screen_new(NvCtrlAttributeHandle *handle,
      * get the data that we will display below
      */
 
-    screen_number = g_strdup_printf("%d", NvCtrlGetTargetId(handle));
-    
-    display_name = NvCtrlGetDisplayName(handle);
-    
+    screen_number = g_strdup_printf("%d", NvCtrlGetTargetId(ctrl_target));
+
+    display_name = NvCtrlGetDisplayName(ctrl_target);
+
     dimensions = g_strdup_printf("%dx%d pixels (%dx%d millimeters)",
-                                 NvCtrlGetScreenWidth(handle),
-                                 NvCtrlGetScreenHeight(handle),
-                                 NvCtrlGetScreenWidthMM(handle),
-                                 NvCtrlGetScreenHeightMM(handle));
+                                 NvCtrlGetScreenWidth(ctrl_target),
+                                 NvCtrlGetScreenHeight(ctrl_target),
+                                 NvCtrlGetScreenWidthMM(ctrl_target),
+                                 NvCtrlGetScreenHeightMM(ctrl_target));
     
     /*
      * there are 2.54 centimeters to an inch; so there are 25.4 millimeters.
@@ -334,40 +178,42 @@ GtkWidget* ctk_screen_new(NvCtrlAttributeHandle *handle,
      *         = N * 25.4 pixels / M inch
      */
     
-    xres = (((double) NvCtrlGetScreenWidth(handle)) * 25.4) / 
-        ((double) NvCtrlGetScreenWidthMM(handle));
+    xres = (((double) NvCtrlGetScreenWidth(ctrl_target)) * 25.4) / 
+        ((double) NvCtrlGetScreenWidthMM(ctrl_target));
 
-    yres = (((double) NvCtrlGetScreenHeight(handle)) * 25.4) / 
-        ((double) NvCtrlGetScreenHeightMM(handle));
+    yres = (((double) NvCtrlGetScreenHeight(ctrl_target)) * 25.4) / 
+        ((double) NvCtrlGetScreenHeightMM(ctrl_target));
 
     resolution = g_strdup_printf("%dx%d dots per inch", 
                                  (int) (xres + 0.5),
                                  (int) (yres + 0.5));
     
-    depth = g_strdup_printf("%d", NvCtrlGetScreenPlanes(handle));
+    depth = g_strdup_printf("%d", NvCtrlGetScreenPlanes(ctrl_target));
     
     /* get the list of GPUs driving this (logical) X screen */
 
     gpus = NULL;
-    ret = NvCtrlGetBinaryAttribute(handle,
+    ret = NvCtrlGetBinaryAttribute(ctrl_target,
                                    0,
                                    NV_CTRL_BINARY_DATA_GPUS_USED_BY_LOGICAL_XSCREEN,
                                    (unsigned char **)(&pData),
                                    &len);
     if (ret == NvCtrlSuccess) {
         for (i = 1; i <= pData[0]; i++) {
+            CtrlTarget *gpu_target;
             gchar *tmp_str;
             gchar *gpu_name;
-            Bool valid;
 
-            valid =
-                XNVCTRLQueryTargetStringAttribute(NvCtrlGetDisplayPtr(handle),
-                                                  NV_CTRL_TARGET_TYPE_GPU,
-                                                  pData[i],
-                                                  0,
-                                                  NV_CTRL_STRING_PRODUCT_NAME,
-                                                  &gpu_name);
-            if (!valid) {
+            gpu_target = NvCtrlGetTarget(ctrl_target->system,
+                                         GPU_TARGET, pData[i]);
+            if (gpu_target == NULL) {
+                continue;
+            }
+
+            ret = NvCtrlGetStringAttribute(gpu_target,
+                                           NV_CTRL_STRING_PRODUCT_NAME,
+                                           &gpu_name);
+            if (ret != NvCtrlSuccess) {
                 gpu_name = "Unknown";
             }
             if (gpus) {
@@ -376,8 +222,8 @@ GtkWidget* ctk_screen_new(NvCtrlAttributeHandle *handle,
             } else {
                 tmp_str = g_strdup_printf("%s (GPU %d)", gpu_name, pData[i]);
             }
-            if (valid) {
-                XFree(gpu_name);
+            if (ret == NvCtrlSuccess) {
+                free(gpu_name);
             }
             g_free(gpus);
             gpus = tmp_str;
@@ -385,38 +231,34 @@ GtkWidget* ctk_screen_new(NvCtrlAttributeHandle *handle,
         if (!gpus) {
             gpus = g_strdup("None");
         }
-        XFree(pData);
+        free(pData);
     }
 
     /* get the list of Display Devices displaying this X screen */
 
-    displays = make_display_device_list(handle);
+    displays = make_display_device_list(ctrl_target);
 
     /* get the number of gpu errors occurred */
 
     gpu_errors = 0;
-    ret = NvCtrlGetDisplayAttribute(handle,
-                                    0,
-                                    NV_CTRL_NUM_GPU_ERRORS_RECOVERED,
-                                    (int *)&gpu_errors);
+    ret = NvCtrlGetAttribute(ctrl_target,
+                             NV_CTRL_NUM_GPU_ERRORS_RECOVERED,
+                             (int *)&gpu_errors);
 
     snprintf(tmp, 16, "%d", gpu_errors);
 
-    /* get the stereo mode set for this X screen */
-    ret = NvCtrlGetDisplayAttribute(handle, 0, NV_CTRL_STEREO,
-                                    (int *)&stereo_mode);
-    if (ret != NvCtrlSuccess) {
-        stereo_mode = -1;
-    }
-
     /* now, create the object */
     
     object = g_object_new(CTK_TYPE_SCREEN, NULL);
     ctk_screen = CTK_SCREEN(object);
 
-    /* cache the attribute handle */
+    /* cache the control target */
 
-    ctk_screen->handle = handle;
+    ctk_screen->ctrl_target = ctrl_target;
+
+    /* get the stereo mode set for this X screen */
+    ret = NvCtrlGetAttribute(ctrl_target, NV_CTRL_STEREO, (int *)&stereo_mode);
+    ctk_screen->stereo_available = (ret == NvCtrlSuccess);
 
     /* set container properties of the object */
 
@@ -470,8 +312,20 @@ GtkWidget* ctk_screen_new(NvCtrlAttributeHandle *handle,
     /* gpu errors */
     ctk_screen->gpu_errors =
         add_table_row(table, 19, 0, 0, "Recovered GPU Errors:", 0, 0, tmp);
-    add_table_row(table, 20, 0, 0, "Stereo Mode:", 0, 0,
-                  get_stereo_mode_string(stereo_mode));
+    if (ctk_screen->stereo_available) {
+        add_table_row(table, 20, 0, 0, "Stereo Mode:", 0, 0,
+                      NvCtrlGetStereoModeName(stereo_mode));
+
+        if (stereo_mode != NV_CTRL_STEREO_OFF) {
+            ctk_glstereo = ctk_glstereo_new();
+            if (ctk_glstereo) {
+                hbox = gtk_hbox_new(FALSE, 0);
+                gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
+                gtk_box_pack_start(GTK_BOX(hbox), ctk_glstereo,
+                                   FALSE, FALSE, 0);
+            }
+        }
+    }
 
     g_free(screen_number);
     free(display_name);
@@ -480,12 +334,6 @@ GtkWidget* ctk_screen_new(NvCtrlAttributeHandle *handle,
     g_free(depth);
     g_free(gpus);
     g_free(displays);
-    
-    /* Handle updates to the list of associated display devices */
-    g_signal_connect(G_OBJECT(ctk_event),
-                     CTK_EVENT_NAME(NV_CTRL_ASSOCIATED_DISPLAY_DEVICES),
-                     G_CALLBACK(associated_displays_received),
-                     (gpointer) ctk_screen);
 
     /* Setup widget to handle XRRScreenChangeNotify events */
     g_signal_connect(G_OBJECT(ctk_event), "CTK_EVENT_RRScreenChangeNotify",
@@ -506,6 +354,7 @@ GtkWidget* ctk_screen_new(NvCtrlAttributeHandle *handle,
 
     
 GtkTextBuffer *ctk_screen_create_help(GtkTextTagTable *table,
+                                      CtkScreen *ctk_screen,
                                       const gchar *screen_name)
 {
     GtkTextIter i;
@@ -558,8 +407,10 @@ GtkTextBuffer *ctk_screen_create_help(GtkTextTagTable *table,
                   "GPU received and the NVIDIA X driver successfully recovered "
                   "from.");
 
-    ctk_help_heading(b, &i, "Stereo Mode");
-    ctk_help_para(b, &i, "This is the stereo mode set for the X screen.");
+    if (ctk_screen->stereo_available) {
+        ctk_help_heading(b, &i, "Stereo Mode");
+        ctk_help_para(b, &i, "This is the stereo mode set for the X screen.");
+    }
 
     ctk_help_finish(b);
 
@@ -574,14 +425,21 @@ GtkTextBuffer *ctk_screen_create_help(GtkTextTagTable *table,
  * with the new screen information.
  */
 void ctk_screen_event_handler(GtkWidget *widget,
-                              XRRScreenChangeNotifyEvent *ev,
+                              CtrlEvent *event,
                               gpointer data)
 {
     CtkScreen *ctk_screen = (CtkScreen *) data;
+    gchar *dimensions;
 
-    gchar *dimensions =  g_strdup_printf("%dx%d pixels (%dx%d millimeters)",
-                                         ev->width, ev->height,
-                                         ev->mwidth, ev->mheight);
+    if (event->type != CTRL_EVENT_TYPE_SCREEN_CHANGE) {
+        return;
+    }
+
+    dimensions =  g_strdup_printf("%dx%d pixels (%dx%d millimeters)",
+                                  event->screen_change.width,
+                                  event->screen_change.height,
+                                  event->screen_change.mwidth,
+                                  event->screen_change.mheight);
 
     gtk_label_set_text(GTK_LABEL(ctk_screen->dimensions),
                        dimensions);
@@ -593,30 +451,11 @@ void ctk_screen_event_handler(GtkWidget *widget,
 
 
 /*
- * When the list of associated displays on this screen changes, we should
- * update the display device list shown on the page.
- */
-static void associated_displays_received(GtkObject *object, gpointer arg1,
-                                         gpointer user_data)
-{
-    CtkScreen *ctk_object = CTK_SCREEN(user_data);
-    gchar *str;
-
-    str = make_display_device_list(ctk_object->handle);
-
-    gtk_label_set_text(GTK_LABEL(ctk_object->displays), str);
-
-    g_free(str);
-
-} /* associated_displays_received() */
-
-
-/*
- * When the  number of gpu errors occured changes,
+ * When the number of gpu errors occurred changes,
  * update the count showed on the page.
  */
 
-static void info_update_gpu_error(GtkObject *object, gpointer arg1,
+static void info_update_gpu_error(GObject *object, gpointer arg1,
                                          gpointer data)
 {
     CtkScreen *ctk_screen = (CtkScreen *) data;
@@ -625,11 +464,12 @@ static void info_update_gpu_error(GtkObject *object, gpointer arg1,
     char tmp[16];
 
     /* get the number of gpu errors occurred */
-    ret = NvCtrlGetDisplayAttribute(ctk_screen->handle, 0,
-                                    NV_CTRL_NUM_GPU_ERRORS_RECOVERED,
-                                    (int *)&gpu_errors);
+    ret = NvCtrlGetAttribute(ctk_screen->ctrl_target,
+                             NV_CTRL_NUM_GPU_ERRORS_RECOVERED,
+                             (int *)&gpu_errors);
     if (ret == NvCtrlSuccess) {
         snprintf(tmp, 16, "%d", gpu_errors);
         gtk_label_set_text(GTK_LABEL(ctk_screen->gpu_errors), tmp);
     }
+
 } /* info_update_gpu_error() */
