@@ -34,6 +34,8 @@
 #include "NvCtrlAttributes.h"
 #include "NvCtrlAttributesPrivate.h"
 
+#include "NVCtrlLib.h"
+
 
 
 /*!
@@ -491,6 +493,12 @@ static void add_target_relationships(CtrlTarget *target,
     int len;
     int i;
 
+    /* If no targets of this type exist in the system, don't bother querying
+     * the server about relationships. */
+    if (target->system->targets[target_type] == NULL) {
+        return;
+    }
+
     status = NvCtrlGetBinaryAttribute(target, 0, attr,
                                       (unsigned char **)(&pData), &len);
     if ((status != NvCtrlSuccess) || !pData) {
@@ -678,6 +686,23 @@ static CtrlTarget *nv_alloc_ctrl_target(CtrlSystem *system,
     t->system = system;
     t->targetTypeInfo = targetTypeInfo;
 
+    /*
+     * detect if the given GPU is visible to the X server and silently fail if
+     * it is not; if there is a discrepency between NVML and NV-CONTROL, such as
+     * an eGPU that is invisible to X due to Option "AllowExternalGpus" "true"
+     * not being specified in xorg.conf, it can cause errors down the line.
+     */
+
+    if (target_type == GPU_TARGET) {
+        /* NV_CTRL_DEPTH_30_ALLOWED expected to succeed for any valid device */
+        status = NvCtrlGetAttribute(t, NV_CTRL_DEPTH_30_ALLOWED, &d);
+        if (status != NvCtrlSuccess) {
+            nvfree(t);
+            NvCtrlAttributeClose(handle);
+            return NULL;
+        }
+    }
+
     /*
      * get a name for this target; in the case of
      * X_SCREEN_TARGET targets, just use the string returned
@@ -818,6 +843,7 @@ static Bool load_system_info(CtrlSystem *system, const char *display)
     CtrlTarget *xscreenQueryTarget = NULL;
     CtrlTarget *nvmlQueryTarget = NULL;
     int i, target_type, val, len, target_count;
+    int unused;
     int *pData = NULL;
     const CtrlTargetTypeInfo *targetTypeInfo;
 
@@ -839,6 +865,9 @@ static Bool load_system_info(CtrlSystem *system, const char *display)
         return FALSE;
     }
 
+    system->has_nv_control =
+        XNVCTRLQueryExtension(system->dpy, &unused, &unused);
+
     /* Try to initialize the NVML library */
     nvmlQueryTarget = nv_alloc_ctrl_target(system, GPU_TARGET, 0,
                                    NV_CTRL_ATTRIBUTES_NV_CONTROL_SUBSYSTEM |
